@@ -1,4 +1,3 @@
-/* $Id: ccmlib_memapi.c,v 1.44 2006/04/14 02:41:30 zhenh Exp $ */
 /* 
  * ccmlib_memapi.c: Consensus Cluster Membership API
  *
@@ -20,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <lha_internal.h>
 #define __CCM_LIBRARY__
 #include <ccmlib.h>
 #include <ccm.h>
@@ -150,7 +150,7 @@ static int
 init_llm(mbr_private_t *private)
 {
 	struct IPC_CHANNEL *ch;
-	int 	sockfd, ret;
+	int 	ret;
 	struct IPC_MESSAGE *msg;
 
 	if(private->llm) {
@@ -158,7 +158,7 @@ init_llm(mbr_private_t *private)
 	}
 
 	ch 	   = private->channel;
-	sockfd = ch->ops->get_recv_select_fd(ch);
+	ch->ops->get_recv_select_fd(ch);
 	while(1) {
 		if(ch->ops->waitin(ch) != IPC_OK){
 			ch->ops->destroy(ch);
@@ -266,7 +266,7 @@ get_new_membership(mbr_private_t *private,
 		mbr_track_t **mbr)
 {
 	mbr_track_t *newmbr, *oldmbr;
-	int trans, i, j, in_index, out_index, born;
+	int i, j, in_index, out_index, born;
 	int n_members;
 	
 	int n_nodes = CLLM_GET_NODECOUNT(private->llm);
@@ -277,7 +277,7 @@ get_new_membership(mbr_private_t *private,
  	newmbr = *mbr = (mbr_track_t *)g_malloc(size +
 						sizeof(mbr_track_t)-sizeof(newmbr->m_mem));
 	
-	trans = OC_EV_SET_INSTANCE(newmbr,mbrinfo->trans);
+	OC_EV_SET_INSTANCE(newmbr,mbrinfo->trans);
 	n_members = OC_EV_SET_N_MEMBER(newmbr,mbrinfo->n);
 	OC_EV_SET_SIZE(newmbr, size);
 
@@ -524,9 +524,10 @@ mem_handle_event(class_t *class)
 				if (mbr_track->quorum == old_mbr_track->quorum){
 					oc_type = OC_EV_MS_PRIMARY_RESTORED;
 				}else {
-					cl_log(LOG_ERR, "membership unchanged but quorum changed"
-					       "something is wrong!!!");
-					return FALSE;
+					cl_log(LOG_DEBUG, "membership unchanged but quorum changed");
+					oc_type = quorum?
+						OC_EV_MS_NEW_MEMBERSHIP:
+						OC_EV_MS_INVALID; 
 				}
 
 			} else {
