@@ -1,4 +1,3 @@
-/* $Id: ccmllm.c,v 1.31 2006/06/07 08:29:52 zhenh Exp $ */
 /* 
  * ccmllm.c: Low Level membership routines.
  *
@@ -21,6 +20,7 @@
  *
  */
 
+#include <lha_internal.h>
 #include "ccm.h"
 
 
@@ -60,19 +60,19 @@ llm_get_live_nodecount(llm_info_t *llm)
 }
 
 
-char *
+const char *
 llm_get_nodename(llm_info_t *llm, const int index)
 {
 	if (llm == NULL){
 		ccm_log(LOG_ERR, "%s: NULL pointer",
 		       __FUNCTION__);
-		return  NULL;
+		return "<INVALID LLM POINTER>";
 	}
 	
 	if (index < 0 || index > MAXNODE){
 		ccm_log(LOG_ERR, "%s: index(%d) out of range",
 		       __FUNCTION__, index);
-		return NULL;
+		return "<INVALID NODE INDEX>";
 	}
 	
 	return llm->nodes[index].nodename;
@@ -250,7 +250,7 @@ llm_del(llm_info_t* llm,
 	if (llm->myindex > i){
 		llm->myindex --;
 	}else if (llm->myindex ==i){
-		ccm_log(LOG_ERR, "%s: deleing myself in ccm is not allowed",
+		ccm_log(LOG_ERR, "%s: deleting myself in ccm is not allowed",
 		       __FUNCTION__);
 		return HA_FAIL;
 	}
@@ -333,7 +333,7 @@ llm_add(llm_info_t *llm,
 }
 
 int
-llm_set_joinrequest(llm_info_t* llm, int index, gboolean value)
+llm_set_joinrequest(llm_info_t* llm, int index, gboolean value, int major_trans)
 {
 	if (llm == NULL){
 		ccm_log(LOG_ERR, "%s: NULL pointer",
@@ -348,7 +348,7 @@ llm_set_joinrequest(llm_info_t* llm, int index, gboolean value)
 	}	
 	
 	llm->nodes[index].join_request = value;
-	
+	llm->nodes[index].join_request_major_trans = major_trans;
 	return HA_OK;
 }
 
@@ -372,6 +372,25 @@ llm_get_joinrequest(llm_info_t* llm, int index)
 }
 
 
+gboolean
+llm_get_joinrequest_majortrans(llm_info_t* llm, int index)
+{
+	if (llm == NULL){
+		ccm_log(LOG_ERR, "%s: NULL pointer",
+		       __FUNCTION__);
+		return  FALSE;
+	}
+	
+	if (index < 0 || index > MAXNODE){
+		ccm_log(LOG_ERR, "%s: index(%d) out of range",
+		       __FUNCTION__, index);
+		return FALSE;
+	}	
+	
+	return llm->nodes[index].join_request_major_trans;
+	
+}
+
 int
 llm_set_change(llm_info_t* llm, int index, gboolean value)
 {
@@ -426,8 +445,8 @@ llm_set_uptime(llm_info_t* llm, int index, int uptime)
 	}
 	
 	if (uptime < 0){
-		ccm_log(LOG_ERR, "%s: Negative uptime %d",
-		       __FUNCTION__, uptime);
+		ccm_log(LOG_ERR, "%s: Negative uptime %d for node %d [%s]",
+		       __FUNCTION__, uptime, index, llm_get_nodename(llm,index));
 		return FALSE;
 		       
 	}
